Fixup API check

Fixup API check filename after fpdf_view_c_api_test was moved.

TBR: hnakashima@chromium.org
Change-Id: I49f1015616cb8c8a5d6a9f0646f1e19e8ed94779
Reviewed-on: https://pdfium-review.googlesource.com/29470
Reviewed-by: dsinclair <dsinclair@chromium.org>
Commit-Queue: dsinclair <dsinclair@chromium.org>
diff --git a/testing/tools/api_check.py b/testing/tools/api_check.py
index c41701e..e88af14 100755
--- a/testing/tools/api_check.py
+++ b/testing/tools/api_check.py
@@ -3,7 +3,7 @@
 # Use of this source code is governed by a BSD-style license that can be
 # found in the LICENSE file.
 
 """Verifies exported functions in public/*.h are in fpdfview_c_api_test.c.
 
 This script gathers a list of functions from public/*.h that contain
 FPDF_EXPORT. It then gathers a list of functions from
@@ -101,7 +101,7 @@
   src_path = os.path.dirname(os.path.dirname(os.path.dirname(script_abspath)))
   public_functions = _GetFunctionsFromPublicHeaders(src_path)
 
-  api_test_relative_path = os.path.join('fpdfsdk', 'fpdfview_c_api_test.c')
+  api_test_relative_path = os.path.join('fpdfsdk', 'fpdf_view_c_api_test.c')
   api_test_path = os.path.join(src_path, api_test_relative_path)
   test_functions = _GetFunctionsFromTest(api_test_path)
@@ -3,7 +3,7 @@
 # found in the LICENSE file.
 
-"""Verifies exported functions in public/*.h are in fpdfview_c_api_test.c.
+"""Verifies exported functions in public/*.h are in fpdf_view_c_api_test.c.
 
 This script gathers a list of functions from public/*.h that contain